# Timesheet Excel Editor

This is an application that allows you to edit excel timesheet.

## Requirements

In order to install wxPython, you need to install the Gtk dependency.
Can do it with this command:

```shell
sudo apt-get install libgtk-3-dev
```
## Installation

You can install the package via PyPI:

```shell
pip install TimesheetExcelEditor 
```
